==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/antistring/translations/antistring_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.0">
<context>
    <name>@default</name>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="4"/>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="7"/>
        <source>Antistring</source>
        <translation>Antistring</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="10"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="13"/>
        <source>Enable Antistring</source>
        <translation>Abilita Antistring</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="16"/>
        <source>Block message</source>
        <translation>Blocca messaggio</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="19"/>
        <source>Admonition</source>
        <translation>Ammonizione</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="24"/>
        <location filename="../.configuration-ui-translations.cpp" line="30"/>
        <source>Log</source>
        <translation>Log</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="27"/>
        <source>Write log to file</source>
        <translation>Scrivi il log nel file</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="35"/>
        <source>Conditions</source>
        <translation>Condizioni</translation>
    </message>
</context>
<context>
    <name>Antistring</name>
    <message>
        <location filename="../antistring.cpp" line="118"/>
        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
</source>
        <translation>DATA E TEMPO :: ID :: MESSAGGIO</translation>
    </message>
</context>
<context>
    <name>AntistringConfigurationUiHandler</name>
    <message>
        <location filename="../antistring-configuration-ui-handler.cpp" line="80"/>
        <source>Condition</source>
        <translation>Condizione</translation>
    </message>
    <message>
        <location filename="../antistring-configuration-ui-handler.cpp" line="86"/>
        <source>Don&apos;t use</source>
        <translation>Non usare</translation>
    </message>
    <message>
        <location filename="../antistring-configuration-ui-handler.cpp" line="87"/>
        <source>Factor</source>
        <translation>Fattore</translation>
    </message>
    <message>
        <location filename="../antistring-configuration-ui-handler.cpp" line="90"/>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <location filename="../antistring-configuration-ui-handler.cpp" line="91"/>
        <source>Change</source>
        <translation>Cambia</translation>
    </message>
    <message>
        <location filename="../antistring-configuration-ui-handler.cpp" line="92"/>
        <source>Delete</source>
        <translation>Cancella</translation>
    </message>
</context>
<context>
    <name>AntistringNotification</name>
    <message>
        <location filename="../antistring-notification.cpp" line="43"/>
        <source>Antistring</source>
        <translation>Antistring</translation>
    </message>
    <message>
        <location filename="../antistring-notification.cpp" line="44"/>
        <source>Your interlocutor send you love letter</source>
        <translation>Il tuo interlocutore ti invia una lettera d&apos;amore</translation>
    </message>
</context>
</TS>

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/antistring/translations/antistring_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Antistring</source>
        <translation>Antistring</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Enable Antistring</source>
        <translation>Abilita Antistring</translation>
    </message>
    <message>
        <source>Block message</source>
        <translation>Blocca messaggio</translation>
    </message>
    <message>
        <source>Admonition</source>
        <translation>Ammonizione</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Log</translation>
    </message>
    <message>
        <source>Write log to file</source>
        <translation>Scrivi il log nel file</translation>
    </message>
    <message>
        <source>Conditions</source>
        <translation>Condizioni</translation>
    </message>
    <message>
        <source>Antistring notifications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Antistring</name>
    <message>
        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
</source>
        <translation>DATA E TEMPO :: ID :: MESSAGGIO</translation>
    </message>
</context>
<context>
    <name>AntistringConfigurationUiHandler</name>
    <message>
        <source>Condition</source>
        <translation>Condizione</translation>
    </message>
    <message>
        <source>Don&apos;t use</source>
        <translation>Non usare</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Fattore</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Cambia</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Cancella</translation>
    </message>
</context>
<context>
    <name>AntistringNotification</name>
    <message>
        <source>Antistring</source>
        <translation>Antistring</translation>
    </message>
    <message>
        <source>Your interlocutor send you love letter</source>
        <translation>Il tuo interlocutore ti invia una lettera d&apos;amore</translation>
    </message>
</context>
</TS>
